==> kget-4.14.3.tar.xz: kget-4.14.3/transfer-plugins/bittorrent/advanceddetails/monitor.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Joris Guisson                              *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTMONITOR_H
#define KTMONITOR_H

#include <interfaces/monitorinterface.h>

namespace bt
{
	class TorrentInterface;
}

namespace kt
{
	class PeerView;
	class ChunkDownloadView;
	class FileView;
	
	/**
	@author Joris Guisson
	*/
	class Monitor : public bt::MonitorInterface
	{
		bt::TorrentInterface* tc;
		PeerView* pv;
		ChunkDownloadView* cdv;
		FileView* fv;
	public:
		Monitor(bt::TorrentInterface* tc,PeerView* pv ,ChunkDownloadView* cdv,FileView* fv);
		virtual ~Monitor();
	
		virtual void downloadRemoved(bt::ChunkDownloadInterface* cd);
		virtual void downloadStarted(bt::ChunkDownloadInterface* cd);
		virtual void peerAdded(bt::PeerInterface* peer);
		virtual void peerRemoved(bt::PeerInterface* peer);
		virtual void stopped();
		virtual void destroyed();
		virtual void filePercentageChanged(bt::TorrentFileInterface* file,float percentage);
		virtual void filePreviewChanged(bt::TorrentFileInterface* file,bool preview);
	};
}

#endif

==> kget-19.07.90.tar.xz: kget-19.07.90/transfer-plugins/bittorrent/advanceddetails/monitor.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Joris Guisson                              *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTMONITOR_H
#define KTMONITOR_H

#include <interfaces/monitorinterface.h>

namespace bt
{
	class TorrentInterface;
}

namespace kt
{
	class PeerView;
	class ChunkDownloadView;
	class FileView;
	
	/**
	@author Joris Guisson
	*/
	class Monitor : public bt::MonitorInterface
	{
		bt::TorrentInterface* tc;
		PeerView* pv;
		ChunkDownloadView* cdv;
		FileView* fv;
	public:
		Monitor(bt::TorrentInterface* tc,PeerView* pv ,ChunkDownloadView* cdv,FileView* fv);
		virtual ~Monitor();
	
		virtual void downloadRemoved(bt::ChunkDownloadInterface* cd) override;
		virtual void downloadStarted(bt::ChunkDownloadInterface* cd) override;
		virtual void peerAdded(bt::PeerInterface* peer) override;
		virtual void peerRemoved(bt::PeerInterface* peer) override;
		virtual void stopped() override;
		virtual void destroyed() override;
		virtual void filePercentageChanged(bt::TorrentFileInterface* file,float percentage) override;
		virtual void filePreviewChanged(bt::TorrentFileInterface* file,bool preview) override;
	};
}

#endif
